==> jc-1.4.0.tar.gz: gnu/java/net/protocol/file/Connection.h <==
// public class gnu.java.net.protocol.file.Connection

// class file dependencies
// @dep_class be433a21d0daeb29 gnu_java_net_protocol_file_Connection
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1042c111741aa488 java_net_URLConnection

// header file dependencies
// @dep_header java_net_URLConnection

#include "java/net/URLConnection.h"

#ifndef _JC_gnu_java_net_protocol_file_Connection_H_
#define _JC_gnu_java_net_protocol_file_Connection_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_FilePermission$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_security_Permission$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_file_Connection$sub_refs	_jc_gnu_java_net_protocol_file_Connection$sub_refs;
typedef struct _jc_gnu_java_net_protocol_file_Connection$sub_nonrefs	_jc_gnu_java_net_protocol_file_Connection$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_file_Connection$refs	_jc_gnu_java_net_protocol_file_Connection$refs;
typedef struct _jc_gnu_java_net_protocol_file_Connection$nonrefs	_jc_gnu_java_net_protocol_file_Connection$nonrefs;
typedef struct _jc_gnu_java_net_protocol_file_Connection$object	_jc_gnu_java_net_protocol_file_Connection$object;

typedef struct _jc_gnu_java_net_protocol_file_Connection$fields_struct	_jc_gnu_java_net_protocol_file_Connection$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_file_Connection$vmethods	_jc_gnu_java_net_protocol_file_Connection$vmethods;
typedef const struct _jc_gnu_java_net_protocol_file_Connection$vtable	_jc_gnu_java_net_protocol_file_Connection$vtable;
typedef const struct _jc_gnu_java_net_protocol_file_Connection$vtype	_jc_gnu_java_net_protocol_file_Connection$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_file_Connection$fields_struct {
	struct _jc_java_lang_String$object	*DEFAULT__5fPERMISSION;
};
extern _jc_gnu_java_net_protocol_file_Connection$fields_struct _jc_gnu_java_net_protocol_file_Connection$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_file_Connection$method$_init$52b89ab562ab928f(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *, struct _jc_java_net_URL$object *);

// Virtual methods
extern void _jc_gnu_java_net_protocol_file_Connection$method$connect$47946c90596538d1(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *);
extern jint _jc_gnu_java_net_protocol_file_Connection$method$getContentLength$b5dadbc29a008b07(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_file_Connection$method$getHeaderField$0a5e9452a9a469b9(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_io_InputStream$object *_jc_gnu_java_net_protocol_file_Connection$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *);
extern jlong _jc_gnu_java_net_protocol_file_Connection$method$getLastModified$104f09ee06ce16cc(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *);
extern struct _jc_java_io_OutputStream$object *_jc_gnu_java_net_protocol_file_Connection$method$getOutputStream$1f50a8d1fe1542e3(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *);
extern struct _jc_java_security_Permission$object *_jc_gnu_java_net_protocol_file_Connection$method$getPermission$5ed14cf5cad2ace7(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$connect$47946c90596538d1;
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$getContentLength$b5dadbc29a008b07;
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$getHeaderField$0a5e9452a9a469b9;
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$getLastModified$104f09ee06ce16cc;
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$getOutputStream$1f50a8d1fe1542e3;
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$getPermission$5ed14cf5cad2ace7;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_file_Connection$vmethods {
	void	(*connect$47946c90596538d1)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *);
	jint	(*getContentLength$b5dadbc29a008b07)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *);
	struct _jc_java_lang_String$object	*(*getHeaderField$0a5e9452a9a469b9)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *);
	jlong	(*getLastModified$104f09ee06ce16cc)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *);
	struct _jc_java_io_OutputStream$object	*(*getOutputStream$1f50a8d1fe1542e3)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *);
	struct _jc_java_security_Permission$object	*(*getPermission$5ed14cf5cad2ace7)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_file_Connection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLConnection$vmethods	java_net_URLConnection;
	_jc_gnu_java_net_protocol_file_Connection$vmethods	gnu_java_net_protocol_file_Connection;
};

// Vtype
struct _jc_gnu_java_net_protocol_file_Connection$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_file_Connection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_file_Connection$sub_refs {
	struct _jc_java_io_File$object	*file;
	struct _jc_java_io_InputStream$object	*inputStream;
	struct _jc_java_io_OutputStream$object	*outputStream;
	struct _jc_java_io_FilePermission$object	*permission;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_file_Connection$refs {
    _jc_gnu_java_net_protocol_file_Connection$sub_refs	gnu_java_net_protocol_file_Connection;
    _jc_java_net_URLConnection$sub_refs	java_net_URLConnection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_file_Connection$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_file_Connection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLConnection$sub_nonrefs	java_net_URLConnection;
    _jc_gnu_java_net_protocol_file_Connection$sub_nonrefs	gnu_java_net_protocol_file_Connection;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_file_Connection$object {
	_jc_gnu_java_net_protocol_file_Connection$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_file_Connection$vtype	*vtype;
	_jc_gnu_java_net_protocol_file_Connection$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_file_Connection$vtype _jc_gnu_java_net_protocol_file_Connection$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_file_Connection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_file_Connection$class_object;

#endif	/* _JC_gnu_java_net_protocol_file_Connection_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/file/Connection.h <==
// public class gnu.java.net.protocol.file.Connection

// class file dependencies
// @dep_class 5448d31e6346454e gnu_java_net_protocol_file_Connection
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1042c111741aa488 java_net_URLConnection

// header file dependencies
// @dep_header java_net_URLConnection

#include "java/net/URLConnection.h"

#ifndef _JC_gnu_java_net_protocol_file_Connection_H_
#define _JC_gnu_java_net_protocol_file_Connection_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_FilePermission$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_security_Permission$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_file_Connection$sub_refs	_jc_gnu_java_net_protocol_file_Connection$sub_refs;
typedef struct _jc_gnu_java_net_protocol_file_Connection$sub_nonrefs	_jc_gnu_java_net_protocol_file_Connection$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_file_Connection$refs	_jc_gnu_java_net_protocol_file_Connection$refs;
typedef struct _jc_gnu_java_net_protocol_file_Connection$nonrefs	_jc_gnu_java_net_protocol_file_Connection$nonrefs;
typedef struct _jc_gnu_java_net_protocol_file_Connection$object	_jc_gnu_java_net_protocol_file_Connection$object;

typedef struct _jc_gnu_java_net_protocol_file_Connection$fields_struct	_jc_gnu_java_net_protocol_file_Connection$fields_struct;
typedef const struct _jc_gnu_java_net_protocol_file_Connection$vmethods	_jc_gnu_java_net_protocol_file_Connection$vmethods;
typedef const struct _jc_gnu_java_net_protocol_file_Connection$vtable	_jc_gnu_java_net_protocol_file_Connection$vtable;
typedef const struct _jc_gnu_java_net_protocol_file_Connection$vtype	_jc_gnu_java_net_protocol_file_Connection$vtype;

// Class fields structure
struct _jc_gnu_java_net_protocol_file_Connection$fields_struct {
	struct _jc_java_lang_String$object	*DEFAULT__5fPERMISSION;
};
extern _jc_gnu_java_net_protocol_file_Connection$fields_struct _jc_gnu_java_net_protocol_file_Connection$class_fields;

// Constructors
extern void _jc_gnu_java_net_protocol_file_Connection$method$_init$52b89ab562ab928f(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_net_protocol_file_Connection$method$connect$47946c90596538d1(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_net_protocol_file_Connection$method$getContentLength$b5dadbc29a008b07(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_net_protocol_file_Connection$method$getDirectoryListing$e5753cacbdb9d0c2(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_net_protocol_file_Connection$method$getHeaderField$0a5e9452a9a469b9(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_InputStream$object *_jc_gnu_java_net_protocol_file_Connection$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *) _JC_JCNI_ATTR;
extern jlong _jc_gnu_java_net_protocol_file_Connection$method$getLastModified$104f09ee06ce16cc(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_OutputStream$object *_jc_gnu_java_net_protocol_file_Connection$method$getOutputStream$1f50a8d1fe1542e3(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_Permission$object *_jc_gnu_java_net_protocol_file_Connection$method$getPermission$5ed14cf5cad2ace7(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$connect$47946c90596538d1;
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$getContentLength$b5dadbc29a008b07;
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$getDirectoryListing$e5753cacbdb9d0c2;
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$getHeaderField$0a5e9452a9a469b9;
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$getLastModified$104f09ee06ce16cc;
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$getOutputStream$1f50a8d1fe1542e3;
extern _jc_method _jc_gnu_java_net_protocol_file_Connection$method_info$getPermission$5ed14cf5cad2ace7;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_file_Connection$vmethods {
	void	(*connect$47946c90596538d1)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *) _JC_JCNI_ATTR;
	jint	(*getContentLength$b5dadbc29a008b07)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getDirectoryListing$e5753cacbdb9d0c2)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getHeaderField$0a5e9452a9a469b9)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *) _JC_JCNI_ATTR;
	jlong	(*getLastModified$104f09ee06ce16cc)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_OutputStream$object	*(*getOutputStream$1f50a8d1fe1542e3)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_Permission$object	*(*getPermission$5ed14cf5cad2ace7)(_jc_env *, struct _jc_gnu_java_net_protocol_file_Connection$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_file_Connection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLConnection$vmethods	java_net_URLConnection;
	_jc_gnu_java_net_protocol_file_Connection$vmethods	gnu_java_net_protocol_file_Connection;
};

// Vtype
struct _jc_gnu_java_net_protocol_file_Connection$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_file_Connection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_file_Connection$sub_refs {
	struct _jc_java_io_File$object	*file;
	_jc_byte_array	*directoryListing;
	struct _jc_java_io_InputStream$object	*inputStream;
	struct _jc_java_io_OutputStream$object	*outputStream;
	struct _jc_java_io_FilePermission$object	*permission;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_file_Connection$refs {
    _jc_gnu_java_net_protocol_file_Connection$sub_refs	gnu_java_net_protocol_file_Connection;
    _jc_java_net_URLConnection$sub_refs	java_net_URLConnection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_file_Connection$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_file_Connection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLConnection$sub_nonrefs	java_net_URLConnection;
    _jc_gnu_java_net_protocol_file_Connection$sub_nonrefs	gnu_java_net_protocol_file_Connection;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_file_Connection$object {
	_jc_gnu_java_net_protocol_file_Connection$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_file_Connection$vtype	*vtype;
	_jc_gnu_java_net_protocol_file_Connection$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_file_Connection$vtype _jc_gnu_java_net_protocol_file_Connection$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_file_Connection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_file_Connection$class_object;

#endif	/* _JC_gnu_java_net_protocol_file_Connection_H_ */
